Predict species presence probability or counts using H3 hexagons
Source:R/h3sdm_predict.R
h3sdm_predict.RdUses a fitted tidymodels workflow (from h3sdm_fit_model or a standalone workflow)
to predict species presence probabilities or counts on a new spatial H3 grid.
Automatically generates centroid coordinates (x and y) if missing.
The new_data must contain the same predictor variables as used in model training.
Model mode (classification or regression) is detected automatically.
Value
An sf object with the original geometry and a new column prediction containing
the predicted probability of presence (classification) or predicted count (regression)
for each hexagon.